decode_entry

Function decode_entry 

pub fn decode_entry(
    data: &[u8],
    offset: usize,
) -> Result<(JournalEntry, usize), ChangesetError>
Decode a single journal entry from bytes at the given offset. Returns the entry and the number of bytes consumed.